Package: extraoperators
Title: Extra Binary Relational and Logical Operators
Version: 0.4.0
Authors@R: 
    person(given = "Joshua F.",
           family = "Wiley",
           role = c("aut", "cre"),
           email = "jwiley.psych@gmail.com",
           comment = c(ORCID = "0000-0002-0271-6702"))	   
Author: Joshua F. Wiley [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0271-6702>)
Maintainer: Joshua F. Wiley <jwiley.psych@gmail.com>
URL: https://joshuawiley.com/extraoperators/,
        https://github.com/JWiley/extraoperators
BugReports: https://github.com/JWiley/extraoperators/issues
Description: Speed up common tasks, particularly logical or
  relational comparisons and routine follow up tasks such as finding the
  indices and subsetting. Inspired by mathematics, where something like:
  3 < x < 6 is a standard, elegant and clear way to assert that
  x is both greater than 3 and less than 6
  (see for example <https://en.wikipedia.org/wiki/Relational_operator>),
  a chaining operator is implemented. The chaining operator, %c%,
  allows multiple relational operations to be used in quotes on the right
  hand side for the same object, on the left hand side.
  The %e% operator allows something like set-builder notation 
  (see for example <https://en.wikipedia.org/wiki/Set-builder_notation>) 
  to be used on the right hand side.
  Operators have built in prefixes defined for all, any, subset, and which
  to reduce the amount of code needed for common tasks, such as return those
  values that are true.
License: GPL-3
Encoding: UTF-8
Suggests: testthat (>= 3.0.0), covr, knitr, rmarkdown
Config/testthat/edition: 3
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-19 08:11:34 UTC; jwile
Repository: CRAN
Date/Publication: 2026-05-20 08:20:02 UTC
Built: R 4.6.0; ; 2026-05-22 00:13:59 UTC; unix
